import java.awt.*;
import java.awt.event.*;
/**
* CSortFrame bekommt fuer die Windowevents die Schnittstelle WindowListener. Initialisiert das Frame und reagiert auf das WindowClosing-Event.
*
* @author Mirko Mumberg
* @version 1.0  date : 07.06.1997 
*/
public class CSortFrame extends Frame implements WindowListener
{
	private CSortCanvas 	m_SortCanvas;			// Die Grafische Oberflaeche des Arrays. 
	private int		m_ElementSize;			// Groesse der Quadratekante in Pixel.
	private int		m_ArraySize;			// Groesse des zusortierenden Arrays.
	private Panel		m_ChoicePanel;			// Panel zur Formatierung.
	private Panel		m_CounterPanel;			// Panel zur Formatierung.
	private CCounter	m_CounterGet, m_CounterSet, m_CounterCompare;	// Counter fuer die Statistik.
	private CSortMenuBar  	m_SortMenuBar;			// Das Menue.
	private Label 		m_SortierMethode;		// Ein Label, das die Sortier-Methode anzeigt.

	/**
	* In dem Konstruktor wird die Initialisierung vom Menue und der Chioce-Elemente vorgenommen. Die Groesse wird mit 30 und die Verzoegerung mit 100 ms initialisiert.  
	* @param title Titel des Frames.
	* @param bValue true, wenn Frame als Applikation beendet werden soll.
	*/
	public CSortFrame(String _title)
	{
		super(_title);
		addWindowListener (this);
		setResizable(true);

		m_CounterGet = new CCounter("Gets : ");
		m_CounterSet = new CCounter("Sets : ");
		m_CounterCompare = new CCounter("Compare : ");
		m_CounterPanel = new Panel();
		m_CounterPanel.add(m_CounterGet);
		m_CounterPanel.add(m_CounterSet);
                m_CounterPanel.add(m_CounterCompare);

		m_SortCanvas = new CSortCanvas(30, m_CounterGet, m_CounterSet, m_CounterCompare);
		m_SortierMethode = new Label("SortierMethode");
		m_SortMenuBar =new CSortMenuBar(m_SortCanvas, this, m_SortierMethode);
		setMenuBar(m_SortMenuBar);

		m_ChoicePanel = new Panel();
		m_ChoicePanel.add(m_SortierMethode);
		m_ChoicePanel.add(new CSizeChoice(this, m_SortCanvas, 30, 120, 10, 0, " Values"));
		m_ChoicePanel.add(new CPixelSizeChoice(this, m_SortCanvas, 3, 15, 1, 4, " Pixels"));

		m_ElementSize = 7;
		setSize(30);
		add("North", m_CounterPanel);
		add("Center", m_SortCanvas);
		add("South", m_ChoicePanel);
	}

	/**
	* Setzt die Groesse des Frames so, dass die Choice- und Counter-Elemente sichtbar sind.
	* @param Value Die neue Groesse des zusortierenden Arrays.
	*/
	public void setSize(int Value)
	{
		m_ArraySize = Value;
		setSize();
	}

	/**
	* Setzen der Pixelanzahl der Quadratekanten, die ide Arrayelemente darstellen.
	* @param Pixel Die Pixelanzahl.
	*/
	public void setElementSize(int pixel)
	{
		m_ElementSize = pixel;
		setSize();
	}

	/**
	* Setzt die Groesse des Frames so, dass die Choice- und Counter-Elemente sichtbar sind.
	*/
	private void setSize()
	{
		if ((m_ArraySize * m_ElementSize) < 370 )
			super.setSize(new Dimension(370, m_ArraySize * m_ElementSize + 150));
		else
			super.setSize(new Dimension(m_ArraySize * m_ElementSize + 10, m_ArraySize * m_ElementSize + 150));
	}

	/**
	* Funktion aus der Schnittstelle WindowListener. Wird aufgerufen, wenn das Programm beendet werden soll. 
	* @param e Windowevent
	*/
	public void windowClosing( WindowEvent e)
	{
		dispose();
		System.exit(0);
	}

	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowOpened( WindowEvent e){}
	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowIconified( WindowEvent e){}
	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowDeiconified( WindowEvent e){}
	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowClosed( WindowEvent e){}
	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowActivated( WindowEvent e){}
	/**
	* Das Window-Event wird nicht beachten, muss aber mit aufgefuehrt werden.
	*/
	public void windowDeactivated( WindowEvent e){}
}

